## LiteLLM Enterprise

Code in this folder is licensed under a commercial license. Please review the [LICENSE](./LICENSE.md) file within the /enterprise folder

**These features are covered under the LiteLLM Enterprise contract**

👉 **Using in an Enterprise / Need specific features ?** Meet with us [here](https://calendly.com/d/4mp-gd3-k5k/litellm-1-1-onboarding-chat?month=2024-02)

## Features:
- Custom API / microservice callbacks
- Google Text Moderation API 

